@@ -5,7 +5,8 @@ import sys
 
 import click
 
-from biskotakigold import __version__
+from . import __version__
+
 
 this_file_location = os.path.dirname(os.path.realpath(os.path.abspath(__file__)))
 
@@ -28,15 +29,7 @@ def version_msg():
 def main(
     # verbose,
 ):
-    """TODO Write this content that gets renders when invoking with --help flag!
-
-    Eg:
-    Create a Project from the project template.
-
-    Cookiecutter Python Package is Free/Libre Open Source Software. If you would
-    like to get in touch, please see
-    https://github.com/boromir674/cookiecutter-python-package.
-    """
+    """TODO Write this content that gets renders when invoking with --help flag!"""
     try:
         pass
     except Exception as error:  # pylint: disable=broad-except
